# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/config/core/v3/protocol.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/config/core/v3/protocol.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import extension_pb2 as envoy_dot_config_dot_core_dot_v3_dot_extension__pb2
from envoy.type.v3 import percent_pb2 as envoy_dot_type_dot_v3_dot_percent__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from xds.annotations.v3 import status_pb2 as xds_dot_annotations_dot_v3_dot_status__pb2
from envoy.annotations import deprecation_pb2 as envoy_dot_annotations_dot_deprecation__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#envoy/config/core/v3/protocol.proto\x12\x14\x65nvoy.config.core.v3\x1a$envoy/config/core/v3/extension.proto\x1a\x1b\x65nvoy/type/v3/percent.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1fxds/annotations/v3/status.proto\x1a#envoy/annotations/deprecation.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"A\n\x12TcpProtocolOptions:+\x9a\xc5\x88\x1e&\n$envoy.api.v2.core.TcpProtocolOptions\"\x8d\x01\n\x15QuicKeepAliveSettings\x12/\n\x0cmax_interval\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x43\n\x10initial_interval\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x0e\xfa\x42\x0b\xaa\x01\x08\"\x00\x32\x04\x10\xc0\x84=\"\xe6\x04\n\x13QuicProtocolOptions\x12\x45\n\x16max_concurrent_streams\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02(\x01\x12N\n\x1ainitial_stream_window_size\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x0c\xfa\x42\t*\x07\x18\x80\x80\x80\x08(\x01\x12R\n\x1einitial_connection_window_size\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x0c\xfa\x42\t*\x07\x18\x80\x80\x80\x0c(\x01\x12W\n&num_timeouts_to_trigger_port_migration\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\t\xfa\x42\x06*\x04\x18\x05(\x00\x12I\n\x14\x63onnection_keepalive\x18\x05 \x01(\x0b\x32+.envoy.config.core.v3.QuicKeepAliveSettings\x12\x1a\n\x12\x63onnection_options\x18\x06 \x01(\t\x12!\n\x19\x63lient_connection_options\x18\x07 \x01(\t\x12H\n\x14idle_network_timeout\x18\x08 \x01(\x0b\x32\x19.google.protobuf.DurationB\x0f\xfa\x42\x0c\xaa\x01\t\"\x03\x08\xd8\x04\x32\x02\x08\x01\x12\x37\n\x11max_packet_length\x18\t \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\"\xb1\x01\n\x1bUpstreamHttpProtocolOptions\x12\x10\n\x08\x61uto_sni\x18\x01 \x01(\x08\x12\x1b\n\x13\x61uto_san_validation\x18\x02 \x01(\x08\x12-\n\x18override_auto_sni_header\x18\x03 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x01\xd0\x01\x01:4\x9a\xc5\x88\x1e/\n-envoy.api.v2.core.UpstreamHttpProtocolOptions\"\xa6\x03\n\x1e\x41lternateProtocolsCacheOptions\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12:\n\x0bmax_entries\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02 \x00\x12J\n\x16key_value_store_config\x18\x03 \x01(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfig\x12o\n\x14prepopulated_entries\x18\x04 \x03(\x0b\x32Q.envoy.config.core.v3.AlternateProtocolsCacheOptions.AlternateProtocolsCacheEntry\x12\x1a\n\x12\x63\x61nonical_suffixes\x18\x05 \x03(\t\x1aX\n\x1c\x41lternateProtocolsCacheEntry\x12\x1d\n\x08hostname\x18\x01 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x01\xd0\x01\x01\x12\x19\n\x04port\x18\x02 \x01(\rB\x0b\xfa\x42\x08*\x06\x10\xff\xff\x03 \x00\"\xf9\x04\n\x13HttpProtocolOptions\x12/\n\x0cidle_timeout\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12:\n\x17max_connection_duration\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12@\n\x11max_headers_count\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02(\x01\x12I\n\x17max_response_headers_kb\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\n\xfa\x42\x07*\x05\x18\x80@ \x00\x12\x36\n\x13max_stream_duration\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12o\n\x1fheaders_with_underscores_action\x18\x05 \x01(\x0e\x32\x46.envoy.config.core.v3.HttpProtocolOptions.HeadersWithUnderscoresAction\x12\x41\n\x1bmax_requests_per_connection\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\"N\n\x1cHeadersWithUnderscoresAction\x12\t\n\x05\x41LLOW\x10\x00\x12\x12\n\x0eREJECT_REQUEST\x10\x01\x12\x0f\n\x0b\x44ROP_HEADER\x10\x02:,\x9a\xc5\x88\x1e\'\n%envoy.api.v2.core.HttpProtocolOptions\"\xa0\x07\n\x14Http1ProtocolOptions\x12\x36\n\x12\x61llow_absolute_url\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x16\n\x0e\x61\x63\x63\x65pt_http_10\x18\x02 \x01(\x08\x12 \n\x18\x64\x65\x66\x61ult_host_for_http_10\x18\x03 \x01(\t\x12U\n\x11header_key_format\x18\x04 \x01(\x0b\x32:.envoy.config.core.v3.Http1ProtocolOptions.HeaderKeyFormat\x12\x17\n\x0f\x65nable_trailers\x18\x05 \x01(\x08\x12\x1c\n\x14\x61llow_chunked_length\x18\x06 \x01(\x08\x12Q\n-override_stream_error_on_invalid_http_message\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12 \n\x18send_fully_qualified_url\x18\x08 \x01(\x08\x12>\n\x10use_balsa_parser\x18\t \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\x08\xd2\xc6\xa4\xe1\x06\x02\x08\x01\x12&\n\x14\x61llow_custom_methods\x18\n \x01(\x08\x42\x08\xd2\xc6\xa4\xe1\x06\x02\x08\x01\x1a\xfb\x02\n\x0fHeaderKeyFormat\x12g\n\x11proper_case_words\x18\x01 \x01(\x0b\x32J.envoy.config.core.v3.Http1ProtocolOptions.HeaderKeyFormat.ProperCaseWordsH\x00\x12H\n\x12stateful_formatter\x18\x08 \x01(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfigH\x00\x1a`\n\x0fProperCaseWords:M\x9a\xc5\x88\x1eH\nFenvoy.api.v2.core.Http1ProtocolOptions.HeaderKeyFormat.ProperCaseWords:=\x9a\xc5\x88\x1e\x38\n6envoy.api.v2.core.Http1ProtocolOptions.HeaderKeyFormatB\x14\n\rheader_format\x12\x03\xf8\x42\x01:-\x9a\xc5\x88\x1e(\n&envoy.api.v2.core.Http1ProtocolOptions\"\x86\x02\n\x11KeepaliveSettings\x12\x39\n\x08interval\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB\x0c\xfa\x42\t\xaa\x01\x06\x32\x04\x10\xc0\x84=\x12:\n\x07timeout\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x0e\xfa\x42\x0b\xaa\x01\x08\x08\x01\x32\x04\x10\xc0\x84=\x12/\n\x0finterval_jitter\x18\x03 \x01(\x0b\x32\x16.envoy.type.v3.Percent\x12I\n\x18\x63onnection_idle_interval\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationB\x0c\xfa\x42\t\xaa\x01\x06\x32\x04\x10\xc0\x84=\"\xc4\x0b\n\x14Http2ProtocolOptions\x12\x36\n\x10hpack_table_size\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12K\n\x16max_concurrent_streams\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\r\xfa\x42\n*\x08\x18\xff\xff\xff\xff\x07(\x01\x12Q\n\x1ainitial_stream_window_size\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x0f\xfa\x42\x0c*\n\x18\xff\xff\xff\xff\x07(\xff\xff\x03\x12U\n\x1einitial_connection_window_size\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x0f\xfa\x42\x0c*\n\x18\xff\xff\xff\xff\x07(\xff\xff\x03\x12\x15\n\rallow_connect\x18\x05 \x01(\x08\x12\x16\n\x0e\x61llow_metadata\x18\x06 \x01(\x08\x12\x42\n\x13max_outbound_frames\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02(\x01\x12J\n\x1bmax_outbound_control_frames\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02(\x01\x12W\n1max_consecutive_inbound_frames_with_empty_payload\x18\t \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12L\n&max_inbound_priority_frames_per_stream\x18\n \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x63\n4max_inbound_window_update_frames_per_data_frame_sent\x18\x0b \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02(\x01\x12;\n&stream_error_on_invalid_http_messaging\x18\x0c \x01(\x08\x42\x0b\x18\x01\x92\xc7\x86\xd8\x04\x03\x33.0\x12Q\n-override_stream_error_on_invalid_http_message\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12`\n\x1a\x63ustom_settings_parameters\x18\r \x03(\x0b\x32<.envoy.config.core.v3.Http2ProtocolOptions.SettingsParameter\x12\x45\n\x14\x63onnection_keepalive\x18\x0f \x01(\x0b\x32\'.envoy.config.core.v3.KeepaliveSettings\x12?\n\x11use_oghttp2_codec\x18\x10 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\x08\xd2\xc6\xa4\xe1\x06\x02\x08\x01\x12\x37\n\x11max_metadata_size\x18\x11 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x1a\xcf\x01\n\x11SettingsParameter\x12\x42\n\nidentifier\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x10\xfa\x42\r*\x06\x18\xff\xff\x03(\x00\x8a\x01\x02\x10\x01\x12\x35\n\x05value\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01:?\x9a\xc5\x88\x1e:\n8envoy.api.v2.core.Http2ProtocolOptions.SettingsParameter:-\x9a\xc5\x88\x1e(\n&envoy.api.v2.core.Http2ProtocolOptions\"\x8f\x01\n\x13GrpcProtocolOptions\x12J\n\x16http2_protocol_options\x18\x01 \x01(\x0b\x32*.envoy.config.core.v3.Http2ProtocolOptions:,\x9a\xc5\x88\x1e\'\n%envoy.api.v2.core.GrpcProtocolOptions\"\xf5\x01\n\x14Http3ProtocolOptions\x12H\n\x15quic_protocol_options\x18\x01 \x01(\x0b\x32).envoy.config.core.v3.QuicProtocolOptions\x12Q\n-override_stream_error_on_invalid_http_message\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12(\n\x16\x61llow_extended_connect\x18\x05 \x01(\x08\x42\x08\xd2\xc6\xa4\xe1\x06\x02\x08\x01\x12\x16\n\x0e\x61llow_metadata\x18\x06 \x01(\x08\"y\n\x1aSchemeHeaderTransformation\x12\x31\n\x13scheme_to_overwrite\x18\x01 \x01(\tB\x12\xfa\x42\x0fr\rR\x04httpR\x05httpsH\x00\x12\x16\n\x0ematch_upstream\x18\x02 \x01(\x08\x42\x10\n\x0etransformationB\x81\x01\n\"io.envoyproxy.envoy.config.core.v3B\rProtocolProtoP\x01ZBgithub.com/envoyproxy/go-control-plane/envoy/config/core/v3;corev3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.core.v3.protocol_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"io.envoyproxy.envoy.config.core.v3B\rProtocolProtoP\001ZBgithub.com/envoyproxy/go-control-plane/envoy/config/core/v3;corev3\272\200\310\321\006\002\020\002'
  _globals['_TCPPROTOCOLOPTIONS']._loaded_options = None
  _globals['_TCPPROTOCOLOPTIONS']._serialized_options = b'\232\305\210\036&\n$envoy.api.v2.core.TcpProtocolOptions'
  _globals['_QUICKEEPALIVESETTINGS'].fields_by_name['initial_interval']._loaded_options = None
  _globals['_QUICKEEPALIVESETTINGS'].fields_by_name['initial_interval']._serialized_options = b'\372B\013\252\001\010\"\0002\004\020\300\204='
  _globals['_QUICPROTOCOLOPTIONS'].fields_by_name['max_concurrent_streams']._loaded_options = None
  _globals['_QUICPROTOCOLOPTIONS'].fields_by_name['max_concurrent_streams']._serialized_options = b'\372B\004*\002(\001'
  _globals['_QUICPROTOCOLOPTIONS'].fields_by_name['initial_stream_window_size']._loaded_options = None
  _globals['_QUICPROTOCOLOPTIONS'].fields_by_name['initial_stream_window_size']._serialized_options = b'\372B\t*\007\030\200\200\200\010(\001'
  _globals['_QUICPROTOCOLOPTIONS'].fields_by_name['initial_connection_window_size']._loaded_options = None
  _globals['_QUICPROTOCOLOPTIONS'].fields_by_name['initial_connection_window_size']._serialized_options = b'\372B\t*\007\030\200\200\200\014(\001'
  _globals['_QUICPROTOCOLOPTIONS'].fields_by_name['num_timeouts_to_trigger_port_migration']._loaded_options = None
  _globals['_QUICPROTOCOLOPTIONS'].fields_by_name['num_timeouts_to_trigger_port_migration']._serialized_options = b'\372B\006*\004\030\005(\000'
  _globals['_QUICPROTOCOLOPTIONS'].fields_by_name['idle_network_timeout']._loaded_options = None
  _globals['_QUICPROTOCOLOPTIONS'].fields_by_name['idle_network_timeout']._serialized_options = b'\372B\014\252\001\t\"\003\010\330\0042\002\010\001'
  _globals['_UPSTREAMHTTPPROTOCOLOPTIONS'].fields_by_name['override_auto_sni_header']._loaded_options = None
  _globals['_UPSTREAMHTTPPROTOCOLOPTIONS'].fields_by_name['override_auto_sni_header']._serialized_options = b'\372B\010r\006\300\001\001\320\001\001'
  _globals['_UPSTREAMHTTPPROTOCOLOPTIONS']._loaded_options = None
  _globals['_UPSTREAMHTTPPROTOCOLOPTIONS']._serialized_options = b'\232\305\210\036/\n-envoy.api.v2.core.UpstreamHttpProtocolOptions'
  _globals['_ALTERNATEPROTOCOLSCACHEOPTIONS_ALTERNATEPROTOCOLSCACHEENTRY'].fields_by_name['hostname']._loaded_options = None
  _globals['_ALTERNATEPROTOCOLSCACHEOPTIONS_ALTERNATEPROTOCOLSCACHEENTRY'].fields_by_name['hostname']._serialized_options = b'\372B\010r\006\300\001\001\320\001\001'
  _globals['_ALTERNATEPROTOCOLSCACHEOPTIONS_ALTERNATEPROTOCOLSCACHEENTRY'].fields_by_name['port']._loaded_options = None
  _globals['_ALTERNATEPROTOCOLSCACHEOPTIONS_ALTERNATEPROTOCOLSCACHEENTRY'].fields_by_name['port']._serialized_options = b'\372B\010*\006\020\377\377\003 \000'
  _globals['_ALTERNATEPROTOCOLSCACHEOPTIONS'].fields_by_name['name']._loaded_options = None
  _globals['_ALTERNATEPROTOCOLSCACHEOPTIONS'].fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_ALTERNATEPROTOCOLSCACHEOPTIONS'].fields_by_name['max_entries']._loaded_options = None
  _globals['_ALTERNATEPROTOCOLSCACHEOPTIONS'].fields_by_name['max_entries']._serialized_options = b'\372B\004*\002 \000'
  _globals['_HTTPPROTOCOLOPTIONS'].fields_by_name['max_headers_count']._loaded_options = None
  _globals['_HTTPPROTOCOLOPTIONS'].fields_by_name['max_headers_count']._serialized_options = b'\372B\004*\002(\001'
  _globals['_HTTPPROTOCOLOPTIONS'].fields_by_name['max_response_headers_kb']._loaded_options = None
  _globals['_HTTPPROTOCOLOPTIONS'].fields_by_name['max_response_headers_kb']._serialized_options = b'\372B\007*\005\030\200@ \000'
  _globals['_HTTPPROTOCOLOPTIONS']._loaded_options = None
  _globals['_HTTPPROTOCOLOPTIONS']._serialized_options = b'\232\305\210\036\'\n%envoy.api.v2.core.HttpProtocolOptions'
  _globals['_HTTP1PROTOCOLOPTIONS_HEADERKEYFORMAT_PROPERCASEWORDS']._loaded_options = None
  _globals['_HTTP1PROTOCOLOPTIONS_HEADERKEYFORMAT_PROPERCASEWORDS']._serialized_options = b'\232\305\210\036H\nFenvoy.api.v2.core.Http1ProtocolOptions.HeaderKeyFormat.ProperCaseWords'
  _globals['_HTTP1PROTOCOLOPTIONS_HEADERKEYFORMAT'].oneofs_by_name['header_format']._loaded_options = None
  _globals['_HTTP1PROTOCOLOPTIONS_HEADERKEYFORMAT'].oneofs_by_name['header_format']._serialized_options = b'\370B\001'
  _globals['_HTTP1PROTOCOLOPTIONS_HEADERKEYFORMAT']._loaded_options = None
  _globals['_HTTP1PROTOCOLOPTIONS_HEADERKEYFORMAT']._serialized_options = b'\232\305\210\0368\n6envoy.api.v2.core.Http1ProtocolOptions.HeaderKeyFormat'
  _globals['_HTTP1PROTOCOLOPTIONS'].fields_by_name['use_balsa_parser']._loaded_options = None
  _globals['_HTTP1PROTOCOLOPTIONS'].fields_by_name['use_balsa_parser']._serialized_options = b'\322\306\244\341\006\002\010\001'
  _globals['_HTTP1PROTOCOLOPTIONS'].fields_by_name['allow_custom_methods']._loaded_options = None
  _globals['_HTTP1PROTOCOLOPTIONS'].fields_by_name['allow_custom_methods']._serialized_options = b'\322\306\244\341\006\002\010\001'
  _globals['_HTTP1PROTOCOLOPTIONS']._loaded_options = None
  _globals['_HTTP1PROTOCOLOPTIONS']._serialized_options = b'\232\305\210\036(\n&envoy.api.v2.core.Http1ProtocolOptions'
  _globals['_KEEPALIVESETTINGS'].fields_by_name['interval']._loaded_options = None
  _globals['_KEEPALIVESETTINGS'].fields_by_name['interval']._serialized_options = b'\372B\t\252\001\0062\004\020\300\204='
  _globals['_KEEPALIVESETTINGS'].fields_by_name['timeout']._loaded_options = None
  _globals['_KEEPALIVESETTINGS'].fields_by_name['timeout']._serialized_options = b'\372B\013\252\001\010\010\0012\004\020\300\204='
  _globals['_KEEPALIVESETTINGS'].fields_by_name['connection_idle_interval']._loaded_options = None
  _globals['_KEEPALIVESETTINGS'].fields_by_name['connection_idle_interval']._serialized_options = b'\372B\t\252\001\0062\004\020\300\204='
  _globals['_HTTP2PROTOCOLOPTIONS_SETTINGSPARAMETER'].fields_by_name['identifier']._loaded_options = None
  _globals['_HTTP2PROTOCOLOPTIONS_SETTINGSPARAMETER'].fields_by_name['identifier']._serialized_options = b'\372B\r*\006\030\377\377\003(\000\212\001\002\020\001'
  _globals['_HTTP2PROTOCOLOPTIONS_SETTINGSPARAMETER'].fields_by_name['value']._loaded_options = None
  _globals['_HTTP2PROTOCOLOPTIONS_SETTINGSPARAMETER'].fields_by_name['value']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_HTTP2PROTOCOLOPTIONS_SETTINGSPARAMETER']._loaded_options = None
  _globals['_HTTP2PROTOCOLOPTIONS_SETTINGSPARAMETER']._serialized_options = b'\232\305\210\036:\n8envoy.api.v2.core.Http2ProtocolOptions.SettingsParameter'
  _globals['_HTTP2PROTOCOLOPTIONS'].fields_by_name['max_concurrent_streams']._loaded_options = None
  _globals['_HTTP2PROTOCOLOPTIONS'].fields_by_name['max_concurrent_streams']._serialized_options = b'\372B\n*\010\030\377\377\377\377\007(\001'
  _globals['_HTTP2PROTOCOLOPTIONS'].fields_by_name['initial_stream_window_size']._loaded_options = None
  _globals['_HTTP2PROTOCOLOPTIONS'].fields_by_name['initial_stream_window_size']._serialized_options = b'\372B\014*\n\030\377\377\377\377\007(\377\377\003'
  _globals['_HTTP2PROTOCOLOPTIONS'].fields_by_name['initial_connection_window_size']._loaded_options = None
  _globals['_HTTP2PROTOCOLOPTIONS'].fields_by_name['initial_connection_window_size']._serialized_options = b'\372B\014*\n\030\377\377\377\377\007(\377\377\003'
  _globals['_HTTP2PROTOCOLOPTIONS'].fields_by_name['max_outbound_frames']._loaded_options = None
  _globals['_HTTP2PROTOCOLOPTIONS'].fields_by_name['max_outbound_frames']._serialized_options = b'\372B\004*\002(\001'
  _globals['_HTTP2PROTOCOLOPTIONS'].fields_by_name['max_outbound_control_frames']._loaded_options = None
  _globals['_HTTP2PROTOCOLOPTIONS'].fields_by_name['max_outbound_control_frames']._serialized_options = b'\372B\004*\002(\001'
  _globals['_HTTP2PROTOCOLOPTIONS'].fields_by_name['max_inbound_window_update_frames_per_data_frame_sent']._loaded_options = None
  _globals['_HTTP2PROTOCOLOPTIONS'].fields_by_name['max_inbound_window_update_frames_per_data_frame_sent']._serialized_options = b'\372B\004*\002(\001'
  _globals['_HTTP2PROTOCOLOPTIONS'].fields_by_name['stream_error_on_invalid_http_messaging']._loaded_options = None
  _globals['_HTTP2PROTOCOLOPTIONS'].fields_by_name['stream_error_on_invalid_http_messaging']._serialized_options = b'\030\001\222\307\206\330\004\0033.0'
  _globals['_HTTP2PROTOCOLOPTIONS'].fields_by_name['use_oghttp2_codec']._loaded_options = None
  _globals['_HTTP2PROTOCOLOPTIONS'].fields_by_name['use_oghttp2_codec']._serialized_options = b'\322\306\244\341\006\002\010\001'
  _globals['_HTTP2PROTOCOLOPTIONS']._loaded_options = None
  _globals['_HTTP2PROTOCOLOPTIONS']._serialized_options = b'\232\305\210\036(\n&envoy.api.v2.core.Http2ProtocolOptions'
  _globals['_GRPCPROTOCOLOPTIONS']._loaded_options = None
  _globals['_GRPCPROTOCOLOPTIONS']._serialized_options = b'\232\305\210\036\'\n%envoy.api.v2.core.GrpcProtocolOptions'
  _globals['_HTTP3PROTOCOLOPTIONS'].fields_by_name['allow_extended_connect']._loaded_options = None
  _globals['_HTTP3PROTOCOLOPTIONS'].fields_by_name['allow_extended_connect']._serialized_options = b'\322\306\244\341\006\002\010\001'
  _globals['_SCHEMEHEADERTRANSFORMATION'].fields_by_name['scheme_to_overwrite']._loaded_options = None
  _globals['_SCHEMEHEADERTRANSFORMATION'].fields_by_name['scheme_to_overwrite']._serialized_options = b'\372B\017r\rR\004httpR\005https'
  _globals['_TCPPROTOCOLOPTIONS']._serialized_start=353
  _globals['_TCPPROTOCOLOPTIONS']._serialized_end=418
  _globals['_QUICKEEPALIVESETTINGS']._serialized_start=421
  _globals['_QUICKEEPALIVESETTINGS']._serialized_end=562
  _globals['_QUICPROTOCOLOPTIONS']._serialized_start=565
  _globals['_QUICPROTOCOLOPTIONS']._serialized_end=1179
  _globals['_UPSTREAMHTTPPROTOCOLOPTIONS']._serialized_start=1182
  _globals['_UPSTREAMHTTPPROTOCOLOPTIONS']._serialized_end=1359
  _globals['_ALTERNATEPROTOCOLSCACHEOPTIONS']._serialized_start=1362
  _globals['_ALTERNATEPROTOCOLSCACHEOPTIONS']._serialized_end=1784
  _globals['_ALTERNATEPROTOCOLSCACHEOPTIONS_ALTERNATEPROTOCOLSCACHEENTRY']._serialized_start=1696
  _globals['_ALTERNATEPROTOCOLSCACHEOPTIONS_ALTERNATEPROTOCOLSCACHEENTRY']._serialized_end=1784
  _globals['_HTTPPROTOCOLOPTIONS']._serialized_start=1787
  _globals['_HTTPPROTOCOLOPTIONS']._serialized_end=2420
  _globals['_HTTPPROTOCOLOPTIONS_HEADERSWITHUNDERSCORESACTION']._serialized_start=2296
  _globals['_HTTPPROTOCOLOPTIONS_HEADERSWITHUNDERSCORESACTION']._serialized_end=2374
  _globals['_HTTP1PROTOCOLOPTIONS']._serialized_start=2423
  _globals['_HTTP1PROTOCOLOPTIONS']._serialized_end=3351
  _globals['_HTTP1PROTOCOLOPTIONS_HEADERKEYFORMAT']._serialized_start=2925
  _globals['_HTTP1PROTOCOLOPTIONS_HEADERKEYFORMAT']._serialized_end=3304
  _globals['_HTTP1PROTOCOLOPTIONS_HEADERKEYFORMAT_PROPERCASEWORDS']._serialized_start=3123
  _globals['_HTTP1PROTOCOLOPTIONS_HEADERKEYFORMAT_PROPERCASEWORDS']._serialized_end=3219
  _globals['_KEEPALIVESETTINGS']._serialized_start=3354
  _globals['_KEEPALIVESETTINGS']._serialized_end=3616
  _globals['_HTTP2PROTOCOLOPTIONS']._serialized_start=3619
  _globals['_HTTP2PROTOCOLOPTIONS']._serialized_end=5095
  _globals['_HTTP2PROTOCOLOPTIONS_SETTINGSPARAMETER']._serialized_start=4841
  _globals['_HTTP2PROTOCOLOPTIONS_SETTINGSPARAMETER']._serialized_end=5048
  _globals['_GRPCPROTOCOLOPTIONS']._serialized_start=5098
  _globals['_GRPCPROTOCOLOPTIONS']._serialized_end=5241
  _globals['_HTTP3PROTOCOLOPTIONS']._serialized_start=5244
  _globals['_HTTP3PROTOCOLOPTIONS']._serialized_end=5489
  _globals['_SCHEMEHEADERTRANSFORMATION']._serialized_start=5491
  _globals['_SCHEMEHEADERTRANSFORMATION']._serialized_end=5612
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/extensions/transport_sockets/tcp_stats/v3/tcp_stats.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/extensions/transport_sockets/tcp_stats/v3/tcp_stats.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?envoy/extensions/transport_sockets/tcp_stats/v3/tcp_stats.proto\x12/envoy.extensions.transport_sockets.tcp_stats.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x93\x01\n\x06\x43onfig\x12I\n\x10transport_socket\x18\x01 \x01(\x0b\x32%.envoy.config.core.v3.TransportSocketB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12>\n\rupdate_period\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x0c\xfa\x42\t\xaa\x01\x06\x32\x04\x10\xc0\x84=B\xbc\x01\n=io.envoyproxy.envoy.extensions.transport_sockets.tcp_stats.v3B\rTcpStatsProtoP\x01Zbgithub.com/envoyproxy/go-control-plane/envoy/extensions/transport_sockets/tcp_stats/v3;tcp_statsv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.transport_sockets.tcp_stats.v3.tcp_stats_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n=io.envoyproxy.envoy.extensions.transport_sockets.tcp_stats.v3B\rTcpStatsProtoP\001Zbgithub.com/envoyproxy/go-control-plane/envoy/extensions/transport_sockets/tcp_stats/v3;tcp_statsv3\272\200\310\321\006\002\020\002'
  _globals['_CONFIG'].fields_by_name['transport_socket']._loaded_options = None
  _globals['_CONFIG'].fields_by_name['transport_socket']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_CONFIG'].fields_by_name['update_period']._loaded_options = None
  _globals['_CONFIG'].fields_by_name['update_period']._serialized_options = b'\372B\t\252\001\0062\004\020\300\204='
  _globals['_CONFIG']._serialized_start=238
  _globals['_CONFIG']._serialized_end=385
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: google/api/apikeys/v2/resources.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'google/api/apikeys/v2/resources.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%google/api/apikeys/v2/resources.proto\x12\x15google.api.apikeys.v2\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa2\x04\n\x03Key\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x03\x12\x10\n\x03uid\x18\x05 \x01(\tB\x03\xe0\x41\x03\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12\x17\n\nkey_string\x18\x03 \x01(\tB\x03\xe0\x41\x03\x12\x34\n\x0b\x63reate_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03\x12\x34\n\x0bupdate_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03\x12\x34\n\x0b\x64\x65lete_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03\x12@\n\x0b\x61nnotations\x18\x08 \x03(\x0b\x32+.google.api.apikeys.v2.Key.AnnotationsEntry\x12\x39\n\x0crestrictions\x18\t \x01(\x0b\x32#.google.api.apikeys.v2.Restrictions\x12\x11\n\x04\x65tag\x18\x0b \x01(\tB\x03\xe0\x41\x03\x1a\x32\n\x10\x41nnotationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01:a\xea\x41^\n\x1a\x61pikeys.googleapis.com/Key\x12\x32projects/{project}/locations/{location}/keys/{key}*\x04keys2\x03keyR\x01\x01\"\x9e\x03\n\x0cRestrictions\x12Q\n\x18\x62rowser_key_restrictions\x18\x01 \x01(\x0b\x32-.google.api.apikeys.v2.BrowserKeyRestrictionsH\x00\x12O\n\x17server_key_restrictions\x18\x02 \x01(\x0b\x32,.google.api.apikeys.v2.ServerKeyRestrictionsH\x00\x12Q\n\x18\x61ndroid_key_restrictions\x18\x03 \x01(\x0b\x32-.google.api.apikeys.v2.AndroidKeyRestrictionsH\x00\x12I\n\x14ios_key_restrictions\x18\x04 \x01(\x0b\x32).google.api.apikeys.v2.IosKeyRestrictionsH\x00\x12\x35\n\x0b\x61pi_targets\x18\x05 \x03(\x0b\x32 .google.api.apikeys.v2.ApiTargetB\x15\n\x13\x63lient_restrictions\"3\n\x16\x42rowserKeyRestrictions\x12\x19\n\x11\x61llowed_referrers\x18\x01 \x03(\t\",\n\x15ServerKeyRestrictions\x12\x13\n\x0b\x61llowed_ips\x18\x01 \x03(\t\"a\n\x16\x41ndroidKeyRestrictions\x12G\n\x14\x61llowed_applications\x18\x01 \x03(\x0b\x32).google.api.apikeys.v2.AndroidApplication\"D\n\x12\x41ndroidApplication\x12\x18\n\x10sha1_fingerprint\x18\x01 \x01(\t\x12\x14\n\x0cpackage_name\x18\x02 \x01(\t\"0\n\x12IosKeyRestrictions\x12\x1a\n\x12\x61llowed_bundle_ids\x18\x01 \x03(\t\"2\n\tApiTarget\x12\x0f\n\x07service\x18\x01 \x01(\t\x12\x14\n\x07methods\x18\x02 \x03(\tB\x03\xe0\x41\x01\x42\xb5\x01\n\x19\x63om.google.api.apikeys.v2B\x0eResourcesProtoP\x01Z5cloud.google.com/go/apikeys/apiv2/apikeyspb;apikeyspb\xaa\x02\x17Google.Cloud.ApiKeys.V2\xca\x02\x17Google\\Cloud\\ApiKeys\\V2\xea\x02\x1aGoogle::Cloud::ApiKeys::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.api.apikeys.v2.resources_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031com.google.api.apikeys.v2B\016ResourcesProtoP\001Z5cloud.google.com/go/apikeys/apiv2/apikeyspb;apikeyspb\252\002\027Google.Cloud.ApiKeys.V2\312\002\027Google\\Cloud\\ApiKeys\\V2\352\002\032Google::Cloud::ApiKeys::V2'
  _globals['_KEY_ANNOTATIONSENTRY']._loaded_options = None
  _globals['_KEY_ANNOTATIONSENTRY']._serialized_options = b'8\001'
  _globals['_KEY'].fields_by_name['name']._loaded_options = None
  _globals['_KEY'].fields_by_name['name']._serialized_options = b'\340A\003'
  _globals['_KEY'].fields_by_name['uid']._loaded_options = None
  _globals['_KEY'].fields_by_name['uid']._serialized_options = b'\340A\003'
  _globals['_KEY'].fields_by_name['key_string']._loaded_options = None
  _globals['_KEY'].fields_by_name['key_string']._serialized_options = b'\340A\003'
  _globals['_KEY'].fields_by_name['create_time']._loaded_options = None
  _globals['_KEY'].fields_by_name['create_time']._serialized_options = b'\340A\003'
  _globals['_KEY'].fields_by_name['update_time']._loaded_options = None
  _globals['_KEY'].fields_by_name['update_time']._serialized_options = b'\340A\003'
  _globals['_KEY'].fields_by_name['delete_time']._loaded_options = None
  _globals['_KEY'].fields_by_name['delete_time']._serialized_options = b'\340A\003'
  _globals['_KEY'].fields_by_name['etag']._loaded_options = None
  _globals['_KEY'].fields_by_name['etag']._serialized_options = b'\340A\003'
  _globals['_KEY']._loaded_options = None
  _globals['_KEY']._serialized_options = b'\352A^\n\032apikeys.googleapis.com/Key\0222projects/{project}/locations/{location}/keys/{key}*\004keys2\003keyR\001\001'
  _globals['_APITARGET'].fields_by_name['methods']._loaded_options = None
  _globals['_APITARGET'].fields_by_name['methods']._serialized_options = b'\340A\001'
  _globals['_KEY']._serialized_start=158
  _globals['_KEY']._serialized_end=704
  _globals['_KEY_ANNOTATIONSENTRY']._serialized_start=555
  _globals['_KEY_ANNOTATIONSENTRY']._serialized_end=605
  _globals['_RESTRICTIONS']._serialized_start=707
  _globals['_RESTRICTIONS']._serialized_end=1121
  _globals['_BROWSERKEYRESTRICTIONS']._serialized_start=1123
  _globals['_BROWSERKEYRESTRICTIONS']._serialized_end=1174
  _globals['_SERVERKEYRESTRICTIONS']._serialized_start=1176
  _globals['_SERVERKEYRESTRICTIONS']._serialized_end=1220
  _globals['_ANDROIDKEYRESTRICTIONS']._serialized_start=1222
  _globals['_ANDROIDKEYRESTRICTIONS']._serialized_end=1319
  _globals['_ANDROIDAPPLICATION']._serialized_start=1321
  _globals['_ANDROIDAPPLICATION']._serialized_end=1389
  _globals['_IOSKEYRESTRICTIONS']._serialized_start=1391
  _globals['_IOSKEYRESTRICTIONS']._serialized_end=1439
  _globals['_APITARGET']._serialized_start=1441
  _globals['_APITARGET']._serialized_end=1491
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/service/redis_auth/v3/redis_external_auth.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/service/redis_auth/v3/redis_external_auth.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5envoy/service/redis_auth/v3/redis_external_auth.proto\x12\x1b\x65nvoy.service.redis_auth.v3\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17google/rpc/status.proto\x1a\x1dudpa/annotations/status.proto\"C\n\x1dRedisProxyExternalAuthRequest\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\"\x85\x01\n\x1eRedisProxyExternalAuthResponse\x12\"\n\x06status\x18\x01 \x01(\x0b\x32\x12.google.rpc.Status\x12.\n\nexpiration\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07message\x18\x03 \x01(\t2\xa4\x01\n\x16RedisProxyExternalAuth\x12\x89\x01\n\x0c\x41uthenticate\x12:.envoy.service.redis_auth.v3.RedisProxyExternalAuthRequest\x1a;.envoy.service.redis_auth.v3.RedisProxyExternalAuthResponse\"\x00\x42\x9e\x01\n)io.envoyproxy.envoy.service.redis_auth.v3B\x16RedisExternalAuthProtoP\x01ZOgithub.com/envoyproxy/go-control-plane/envoy/service/redis_auth/v3;redis_authv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.service.redis_auth.v3.redis_external_auth_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n)io.envoyproxy.envoy.service.redis_auth.v3B\026RedisExternalAuthProtoP\001ZOgithub.com/envoyproxy/go-control-plane/envoy/service/redis_auth/v3;redis_authv3\272\200\310\321\006\002\020\002'
  _globals['_REDISPROXYEXTERNALAUTHREQUEST']._serialized_start=175
  _globals['_REDISPROXYEXTERNALAUTHREQUEST']._serialized_end=242
  _globals['_REDISPROXYEXTERNALAUTHRESPONSE']._serialized_start=245
  _globals['_REDISPROXYEXTERNALAUTHRESPONSE']._serialized_end=378
  _globals['_REDISPROXYEXTERNALAUTH']._serialized_start=381
  _globals['_REDISPROXYEXTERNALAUTH']._serialized_end=545
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/extensions/filters/http/cors/v3/cors.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/extensions/filters/http/cors/v3/cors.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.type.matcher.v3 import string_pb2 as envoy_dot_type_dot_matcher_dot_v3_dot_string__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0envoy/extensions/filters/http/cors/v3/cors.proto\x12%envoy.extensions.filters.http.cors.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a\"envoy/type/matcher/v3/string.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"4\n\x04\x43ors:,\x9a\xc5\x88\x1e\'\n%envoy.config.filter.http.cors.v2.Cors\"\xfa\x03\n\nCorsPolicy\x12G\n\x19\x61llow_origin_string_match\x18\x01 \x03(\x0b\x32$.envoy.type.matcher.v3.StringMatcher\x12\x15\n\rallow_methods\x18\x02 \x01(\t\x12\x15\n\rallow_headers\x18\x03 \x01(\t\x12\x16\n\x0e\x65xpose_headers\x18\x04 \x01(\t\x12\x0f\n\x07max_age\x18\x05 \x01(\t\x12\x35\n\x11\x61llow_credentials\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x46\n\x0e\x66ilter_enabled\x18\x07 \x01(\x0b\x32..envoy.config.core.v3.RuntimeFractionalPercent\x12\x46\n\x0eshadow_enabled\x18\x08 \x01(\x0b\x32..envoy.config.core.v3.RuntimeFractionalPercent\x12@\n\x1c\x61llow_private_network_access\x18\t \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x43\n\x1f\x66orward_not_matching_preflights\x18\n \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\x9f\x01\n3io.envoyproxy.envoy.extensions.filters.http.cors.v3B\tCorsProtoP\x01ZSgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/cors/v3;corsv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.cors.v3.cors_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n3io.envoyproxy.envoy.extensions.filters.http.cors.v3B\tCorsProtoP\001ZSgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/cors/v3;corsv3\272\200\310\321\006\002\020\002'
  _globals['_CORS']._loaded_options = None
  _globals['_CORS']._serialized_options = b'\232\305\210\036\'\n%envoy.config.filter.http.cors.v2.Cors'
  _globals['_CORS']._serialized_start=258
  _globals['_CORS']._serialized_end=310
  _globals['_CORSPOLICY']._serialized_start=313
  _globals['_CORSPOLICY']._serialized_end=819
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/api/v2/core/event_service_config.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/api/v2/core/event_service_config.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import grpc_service_pb2 as envoy_dot_api_dot_v2_dot_core_dot_grpc__service__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,envoy/api/v2/core/event_service_config.proto\x12\x11\x65nvoy.api.v2.core\x1a$envoy/api/v2/core/grpc_service.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"l\n\x12\x45ventServiceConfig\x12\x36\n\x0cgrpc_service\x18\x01 \x01(\x0b\x32\x1e.envoy.api.v2.core.GrpcServiceH\x00\x42\x1e\n\x17\x63onfig_source_specifier\x12\x03\xf8\x42\x01\x42\x9a\x01\n\x1fio.envoyproxy.envoy.api.v2.coreB\x17\x45ventServiceConfigProtoP\x01Z8github.com/envoyproxy/go-control-plane/envoy/api/v2/core\xf2\x98\xfe\x8f\x05\x16\x12\x14\x65nvoy.config.core.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.api.v2.core.event_service_config_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\037io.envoyproxy.envoy.api.v2.coreB\027EventServiceConfigProtoP\001Z8github.com/envoyproxy/go-control-plane/envoy/api/v2/core\362\230\376\217\005\026\022\024envoy.config.core.v3\272\200\310\321\006\002\020\001'
  _globals['_EVENTSERVICECONFIG'].oneofs_by_name['config_source_specifier']._loaded_options = None
  _globals['_EVENTSERVICECONFIG'].oneofs_by_name['config_source_specifier']._serialized_options = b'\370B\001'
  _globals['_EVENTSERVICECONFIG']._serialized_start=193
  _globals['_EVENTSERVICECONFIG']._serialized_end=301
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: google/api/cloudquotas/v1/cloudquotas.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'google/api/cloudquotas/v1/cloudquotas.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api.cloudquotas.v1 import resources_pb2 as google_dot_api_dot_cloudquotas_dot_v1_dot_resources__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+google/api/cloudquotas/v1/cloudquotas.proto\x12\x19google.api.cloudquotas.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x17google/api/client.proto\x1a)google/api/cloudquotas/v1/resources.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a google/protobuf/field_mask.proto\"\x86\x01\n\x15ListQuotaInfosRequest\x12<\n\x06parent\x18\x01 \x01(\tB,\xe0\x41\x02\xfa\x41&\x12$cloudquotas.googleapis.com/QuotaInfo\x12\x16\n\tpage_size\x18\x02 \x01(\x05\x42\x03\xe0\x41\x01\x12\x17\n\npage_token\x18\x03 \x01(\tB\x03\xe0\x41\x01\"l\n\x16ListQuotaInfosResponse\x12\x39\n\x0bquota_infos\x18\x01 \x03(\x0b\x32$.google.api.cloudquotas.v1.QuotaInfo\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"Q\n\x13GetQuotaInfoRequest\x12:\n\x04name\x18\x01 \x01(\tB,\xe0\x41\x02\xfa\x41&\n$cloudquotas.googleapis.com/QuotaInfo\"\xbe\x01\n\x1bListQuotaPreferencesRequest\x12\x42\n\x06parent\x18\x01 \x01(\tB2\xe0\x41\x02\xfa\x41,\x12*cloudquotas.googleapis.com/QuotaPreference\x12\x16\n\tpage_size\x18\x02 \x01(\x05\x42\x03\xe0\x41\x01\x12\x17\n\npage_token\x18\x03 \x01(\tB\x03\xe0\x41\x01\x12\x13\n\x06\x66ilter\x18\x04 \x01(\tB\x03\xe0\x41\x01\x12\x15\n\x08order_by\x18\x05 \x01(\tB\x03\xe0\x41\x01\"\x93\x01\n\x1cListQuotaPreferencesResponse\x12\x45\n\x11quota_preferences\x18\x01 \x03(\x0b\x32*.google.api.cloudquotas.v1.QuotaPreference\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x13\n\x0bunreachable\x18\x03 \x03(\t\"]\n\x19GetQuotaPreferenceRequest\x12@\n\x04name\x18\x01 \x01(\tB2\xe0\x41\x02\xfa\x41,\n*cloudquotas.googleapis.com/QuotaPreference\"\x9a\x02\n\x1c\x43reateQuotaPreferenceRequest\x12\x42\n\x06parent\x18\x01 \x01(\tB2\xe0\x41\x02\xfa\x41,\x12*cloudquotas.googleapis.com/QuotaPreference\x12 \n\x13quota_preference_id\x18\x02 \x01(\tB\x03\xe0\x41\x01\x12I\n\x10quota_preference\x18\x03 \x01(\x0b\x32*.google.api.cloudquotas.v1.QuotaPreferenceB\x03\xe0\x41\x02\x12I\n\x14ignore_safety_checks\x18\x04 \x03(\x0e\x32+.google.api.cloudquotas.v1.QuotaSafetyCheck\"\xa2\x02\n\x1cUpdateQuotaPreferenceRequest\x12\x34\n\x0bupdate_mask\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x03\xe0\x41\x01\x12I\n\x10quota_preference\x18\x02 \x01(\x0b\x32*.google.api.cloudquotas.v1.QuotaPreferenceB\x03\xe0\x41\x02\x12\x1a\n\rallow_missing\x18\x03 \x01(\x08\x42\x03\xe0\x41\x01\x12\x1a\n\rvalidate_only\x18\x04 \x01(\x08\x42\x03\xe0\x41\x01\x12I\n\x14ignore_safety_checks\x18\x05 \x03(\x0e\x32+.google.api.cloudquotas.v1.QuotaSafetyCheck2\xb9\x11\n\x0b\x43loudQuotas\x12\xc1\x02\n\x0eListQuotaInfos\x12\x30.google.api.cloudquotas.v1.ListQuotaInfosRequest\x1a\x31.google.api.cloudquotas.v1.ListQuotaInfosResponse\"\xc9\x01\xda\x41\x06parent\x82\xd3\xe4\x93\x02\xb9\x01\x12\x39/v1/{parent=projects/*/locations/*/services/*}/quotaInfosZ@\x12>/v1/{parent=organizations/*/locations/*/services/*}/quotaInfosZ:\x12\x38/v1/{parent=folders/*/locations/*/services/*}/quotaInfos\x12\xae\x02\n\x0cGetQuotaInfo\x12..google.api.cloudquotas.v1.GetQuotaInfoRequest\x1a$.google.api.cloudquotas.v1.QuotaInfo\"\xc7\x01\xda\x41\x04name\x82\xd3\xe4\x93\x02\xb9\x01\x12\x39/v1/{name=projects/*/locations/*/services/*/quotaInfos/*}Z@\x12>/v1/{name=organizations/*/locations/*/services/*/quotaInfos/*}Z:\x12\x38/v1/{name=folders/*/locations/*/services/*/quotaInfos/*}\x12\xc4\x02\n\x14ListQuotaPreferences\x12\x36.google.api.cloudquotas.v1.ListQuotaPreferencesRequest\x1a\x37.google.api.cloudquotas.v1.ListQuotaPreferencesResponse\"\xba\x01\xda\x41\x06parent\x82\xd3\xe4\x93\x02\xaa\x01\x12\x34/v1/{parent=projects/*/locations/*}/quotaPreferencesZ5\x12\x33/v1/{parent=folders/*/locations/*}/quotaPreferencesZ;\x12\x39/v1/{parent=organizations/*/locations/*}/quotaPreferences\x12\xb1\x02\n\x12GetQuotaPreference\x12\x34.google.api.cloudquotas.v1.GetQuotaPreferenceRequest\x1a*.google.api.cloudquotas.v1.QuotaPreference\"\xb8\x01\xda\x41\x04name\x82\xd3\xe4\x93\x02\xaa\x01\x12\x34/v1/{name=projects/*/locations/*/quotaPreferences/*}Z;\x12\x39/v1/{name=organizations/*/locations/*/quotaPreferences/*}Z5\x12\x33/v1/{name=folders/*/locations/*/quotaPreferences/*}\x12\xae\x03\n\x15\x43reateQuotaPreference\x12\x37.google.api.cloudquotas.v1.CreateQuotaPreferenceRequest\x1a*.google.api.cloudquotas.v1.QuotaPreference\"\xaf\x02\xda\x41+parent,quota_preference,quota_preference_id\xda\x41\x17parent,quota_preference\x82\xd3\xe4\x93\x02\xe0\x01\"4/v1/{parent=projects/*/locations/*}/quotaPreferences:\x10quota_preferenceZG\"3/v1/{parent=folders/*/locations/*}/quotaPreferences:\x10quota_preferenceZM\"9/v1/{parent=organizations/*/locations/*}/quotaPreferences:\x10quota_preference\x12\xb8\x03\n\x15UpdateQuotaPreference\x12\x37.google.api.cloudquotas.v1.UpdateQuotaPreferenceRequest\x1a*.google.api.cloudquotas.v1.QuotaPreference\"\xb9\x02\xda\x41\x1cquota_preference,update_mask\x82\xd3\xe4\x93\x02\x93\x02\x32\x45/v1/{quota_preference.name=projects/*/locations/*/quotaPreferences/*}:\x10quota_preferenceZX2D/v1/{quota_preference.name=folders/*/locations/*/quotaPreferences/*}:\x10quota_preferenceZ^2J/v1/{quota_preference.name=organizations/*/locations/*/quotaPreferences/*}:\x10quota_preference\x1aN\xca\x41\x1a\x63loudquotas.googleapis.com\xd2\x41.https://www.googleapis.com/auth/cloud-platformB\xe3\x04\n\x1d\x63om.google.api.cloudquotas.v1B\x10\x43loudquotasProtoP\x01ZAcloud.google.com/go/cloudquotas/apiv1/cloudquotaspb;cloudquotaspb\xaa\x02\x1bGoogle.Cloud.CloudQuotas.V1\xca\x02\x1bGoogle\\Cloud\\CloudQuotas\\V1\xea\x02\x1eGoogle::Cloud::CloudQuotas::V1\xea\x41\xe0\x01\n\"cloudquotas.googleapis.com/Service\x12:projects/{project}/locations/{location}/services/{service}\x12\x38\x66olders/{folder}/locations/{location}/services/{service}\x12\x44organizations/{organization}/locations/{location}/services/{service}\xea\x41\xa8\x01\n#cloudquotas.googleapis.com/Location\x12\'projects/{project}/locations/{location}\x12%folders/{folder}/locations/{location}\x12\x31organizations/{organization}/locations/{location}b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.api.cloudquotas.v1.cloudquotas_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\035com.google.api.cloudquotas.v1B\020CloudquotasProtoP\001ZAcloud.google.com/go/cloudquotas/apiv1/cloudquotaspb;cloudquotaspb\252\002\033Google.Cloud.CloudQuotas.V1\312\002\033Google\\Cloud\\CloudQuotas\\V1\352\002\036Google::Cloud::CloudQuotas::V1\352A\340\001\n\"cloudquotas.googleapis.com/Service\022:projects/{project}/locations/{location}/services/{service}\0228folders/{folder}/locations/{location}/services/{service}\022Dorganizations/{organization}/locations/{location}/services/{service}\352A\250\001\n#cloudquotas.googleapis.com/Location\022\'projects/{project}/locations/{location}\022%folders/{folder}/locations/{location}\0221organizations/{organization}/locations/{location}'
  _globals['_LISTQUOTAINFOSREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_LISTQUOTAINFOSREQUEST'].fields_by_name['parent']._serialized_options = b'\340A\002\372A&\022$cloudquotas.googleapis.com/QuotaInfo'
  _globals['_LISTQUOTAINFOSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTQUOTAINFOSREQUEST'].fields_by_name['page_size']._serialized_options = b'\340A\001'
  _globals['_LISTQUOTAINFOSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTQUOTAINFOSREQUEST'].fields_by_name['page_token']._serialized_options = b'\340A\001'
  _globals['_GETQUOTAINFOREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETQUOTAINFOREQUEST'].fields_by_name['name']._serialized_options = b'\340A\002\372A&\n$cloudquotas.googleapis.com/QuotaInfo'
  _globals['_LISTQUOTAPREFERENCESREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_LISTQUOTAPREFERENCESREQUEST'].fields_by_name['parent']._serialized_options = b'\340A\002\372A,\022*cloudquotas.googleapis.com/QuotaPreference'
  _globals['_LISTQUOTAPREFERENCESREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTQUOTAPREFERENCESREQUEST'].fields_by_name['page_size']._serialized_options = b'\340A\001'
  _globals['_LISTQUOTAPREFERENCESREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTQUOTAPREFERENCESREQUEST'].fields_by_name['page_token']._serialized_options = b'\340A\001'
  _globals['_LISTQUOTAPREFERENCESREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTQUOTAPREFERENCESREQUEST'].fields_by_name['filter']._serialized_options = b'\340A\001'
  _globals['_LISTQUOTAPREFERENCESREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTQUOTAPREFERENCESREQUEST'].fields_by_name['order_by']._serialized_options = b'\340A\001'
  _globals['_GETQUOTAPREFERENCEREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETQUOTAPREFERENCEREQUEST'].fields_by_name['name']._serialized_options = b'\340A\002\372A,\n*cloudquotas.googleapis.com/QuotaPreference'
  _globals['_CREATEQUOTAPREFERENCEREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_CREATEQUOTAPREFERENCEREQUEST'].fields_by_name['parent']._serialized_options = b'\340A\002\372A,\022*cloudquotas.googleapis.com/QuotaPreference'
  _globals['_CREATEQUOTAPREFERENCEREQUEST'].fields_by_name['quota_preference_id']._loaded_options = None
  _globals['_CREATEQUOTAPREFERENCEREQUEST'].fields_by_name['quota_preference_id']._serialized_options = b'\340A\001'
  _globals['_CREATEQUOTAPREFERENCEREQUEST'].fields_by_name['quota_preference']._loaded_options = None
  _globals['_CREATEQUOTAPREFERENCEREQUEST'].fields_by_name['quota_preference']._serialized_options = b'\340A\002'
  _globals['_UPDATEQUOTAPREFERENCEREQUEST'].fields_by_name['update_mask']._loaded_options = None
  _globals['_UPDATEQUOTAPREFERENCEREQUEST'].fields_by_name['update_mask']._serialized_options = b'\340A\001'
  _globals['_UPDATEQUOTAPREFERENCEREQUEST'].fields_by_name['quota_preference']._loaded_options = None
  _globals['_UPDATEQUOTAPREFERENCEREQUEST'].fields_by_name['quota_preference']._serialized_options = b'\340A\002'
  _globals['_UPDATEQUOTAPREFERENCEREQUEST'].fields_by_name['allow_missing']._loaded_options = None
  _globals['_UPDATEQUOTAPREFERENCEREQUEST'].fields_by_name['allow_missing']._serialized_options = b'\340A\001'
  _globals['_UPDATEQUOTAPREFERENCEREQUEST'].fields_by_name['validate_only']._loaded_options = None
  _globals['_UPDATEQUOTAPREFERENCEREQUEST'].fields_by_name['validate_only']._serialized_options = b'\340A\001'
  _globals['_CLOUDQUOTAS']._loaded_options = None
  _globals['_CLOUDQUOTAS']._serialized_options = b'\312A\032cloudquotas.googleapis.com\322A.https://www.googleapis.com/auth/cloud-platform'
  _globals['_CLOUDQUOTAS'].methods_by_name['ListQuotaInfos']._loaded_options = None
  _globals['_CLOUDQUOTAS'].methods_by_name['ListQuotaInfos']._serialized_options = b'\332A\006parent\202\323\344\223\002\271\001\0229/v1/{parent=projects/*/locations/*/services/*}/quotaInfosZ@\022>/v1/{parent=organizations/*/locations/*/services/*}/quotaInfosZ:\0228/v1/{parent=folders/*/locations/*/services/*}/quotaInfos'
  _globals['_CLOUDQUOTAS'].methods_by_name['GetQuotaInfo']._loaded_options = None
  _globals['_CLOUDQUOTAS'].methods_by_name['GetQuotaInfo']._serialized_options = b'\332A\004name\202\323\344\223\002\271\001\0229/v1/{name=projects/*/locations/*/services/*/quotaInfos/*}Z@\022>/v1/{name=organizations/*/locations/*/services/*/quotaInfos/*}Z:\0228/v1/{name=folders/*/locations/*/services/*/quotaInfos/*}'
  _globals['_CLOUDQUOTAS'].methods_by_name['ListQuotaPreferences']._loaded_options = None
  _globals['_CLOUDQUOTAS'].methods_by_name['ListQuotaPreferences']._serialized_options = b'\332A\006parent\202\323\344\223\002\252\001\0224/v1/{parent=projects/*/locations/*}/quotaPreferencesZ5\0223/v1/{parent=folders/*/locations/*}/quotaPreferencesZ;\0229/v1/{parent=organizations/*/locations/*}/quotaPreferences'
  _globals['_CLOUDQUOTAS'].methods_by_name['GetQuotaPreference']._loaded_options = None
  _globals['_CLOUDQUOTAS'].methods_by_name['GetQuotaPreference']._serialized_options = b'\332A\004name\202\323\344\223\002\252\001\0224/v1/{name=projects/*/locations/*/quotaPreferences/*}Z;\0229/v1/{name=organizations/*/locations/*/quotaPreferences/*}Z5\0223/v1/{name=folders/*/locations/*/quotaPreferences/*}'
  _globals['_CLOUDQUOTAS'].methods_by_name['CreateQuotaPreference']._loaded_options = None
  _globals['_CLOUDQUOTAS'].methods_by_name['CreateQuotaPreference']._serialized_options = b'\332A+parent,quota_preference,quota_preference_id\332A\027parent,quota_preference\202\323\344\223\002\340\001\"4/v1/{parent=projects/*/locations/*}/quotaPreferences:\020quota_preferenceZG\"3/v1/{parent=folders/*/locations/*}/quotaPreferences:\020quota_preferenceZM\"9/v1/{parent=organizations/*/locations/*}/quotaPreferences:\020quota_preference'
  _globals['_CLOUDQUOTAS'].methods_by_name['UpdateQuotaPreference']._loaded_options = None
  _globals['_CLOUDQUOTAS'].methods_by_name['UpdateQuotaPreference']._serialized_options = b'\332A\034quota_preference,update_mask\202\323\344\223\002\223\0022E/v1/{quota_preference.name=projects/*/locations/*/quotaPreferences/*}:\020quota_preferenceZX2D/v1/{quota_preference.name=folders/*/locations/*/quotaPreferences/*}:\020quota_preferenceZ^2J/v1/{quota_preference.name=organizations/*/locations/*/quotaPreferences/*}:\020quota_preference'
  _globals['_LISTQUOTAINFOSREQUEST']._serialized_start=267
  _globals['_LISTQUOTAINFOSREQUEST']._serialized_end=401
  _globals['_LISTQUOTAINFOSRESPONSE']._serialized_start=403
  _globals['_LISTQUOTAINFOSRESPONSE']._serialized_end=511
  _globals['_GETQUOTAINFOREQUEST']._serialized_start=513
  _globals['_GETQUOTAINFOREQUEST']._serialized_end=594
  _globals['_LISTQUOTAPREFERENCESREQUEST']._serialized_start=597
  _globals['_LISTQUOTAPREFERENCESREQUEST']._serialized_end=787
  _globals['_LISTQUOTAPREFERENCESRESPONSE']._serialized_start=790
  _globals['_LISTQUOTAPREFERENCESRESPONSE']._serialized_end=937
  _globals['_GETQUOTAPREFERENCEREQUEST']._serialized_start=939
  _globals['_GETQUOTAPREFERENCEREQUEST']._serialized_end=1032
  _globals['_CREATEQUOTAPREFERENCEREQUEST']._serialized_start=1035
  _globals['_CREATEQUOTAPREFERENCEREQUEST']._serialized_end=1317
  _globals['_UPDATEQUOTAPREFERENCEREQUEST']._serialized_start=1320
  _globals['_UPDATEQUOTAPREFERENCEREQUEST']._serialized_end=1610
  _globals['_CLOUDQUOTAS']._serialized_start=1613
  _globals['_CLOUDQUOTAS']._serialized_end=3846
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/config/common/mutation_rules/v3/mutation_rules.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/config/common/mutation_rules/v3/mutation_rules.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.type.matcher.v3 import regex_pb2 as envoy_dot_type_dot_matcher_dot_v3_dot_regex__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:envoy/config/common/mutation_rules/v3/mutation_rules.proto\x12%envoy.config.common.mutation_rules.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a!envoy/type/matcher/v3/regex.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x9c\x03\n\x13HeaderMutationRules\x12\x35\n\x11\x61llow_all_routing\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12/\n\x0b\x61llow_envoy\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x33\n\x0f\x64isallow_system\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x30\n\x0c\x64isallow_all\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12=\n\x10\x61llow_expression\x18\x05 \x01(\x0b\x32#.envoy.type.matcher.v3.RegexMatcher\x12@\n\x13\x64isallow_expression\x18\x06 \x01(\x0b\x32#.envoy.type.matcher.v3.RegexMatcher\x12\x35\n\x11\x64isallow_is_error\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"y\n\x0eHeaderMutation\x12\x1d\n\x06remove\x18\x01 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x02\xc8\x01\x00H\x00\x12\x39\n\x06\x61ppend\x18\x02 \x01(\x0b\x32\'.envoy.config.core.v3.HeaderValueOptionH\x00\x42\r\n\x06\x61\x63tion\x12\x03\xf8\x42\x01\x42\xb2\x01\n3io.envoyproxy.envoy.config.common.mutation_rules.v3B\x12MutationRulesProtoP\x01Z]github.com/envoyproxy/go-control-plane/envoy/config/common/mutation_rules/v3;mutation_rulesv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.common.mutation_rules.v3.mutation_rules_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n3io.envoyproxy.envoy.config.common.mutation_rules.v3B\022MutationRulesProtoP\001Z]github.com/envoyproxy/go-control-plane/envoy/config/common/mutation_rules/v3;mutation_rulesv3\272\200\310\321\006\002\020\002'
  _globals['_HEADERMUTATION'].oneofs_by_name['action']._loaded_options = None
  _globals['_HEADERMUTATION'].oneofs_by_name['action']._serialized_options = b'\370B\001'
  _globals['_HEADERMUTATION'].fields_by_name['remove']._loaded_options = None
  _globals['_HEADERMUTATION'].fields_by_name['remove']._serialized_options = b'\372B\010r\006\300\001\002\310\001\000'
  _globals['_HEADERMUTATIONRULES']._serialized_start=258
  _globals['_HEADERMUTATIONRULES']._serialized_end=670
  _globals['_HEADERMUTATION']._serialized_start=672
  _globals['_HEADERMUTATION']._serialized_end=793
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/config/accesslog/v2/file.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/config/accesslog/v2/file.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$envoy/config/accesslog/v2/file.proto\x12\x19\x65nvoy.config.accesslog.v2\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xb3\x01\n\rFileAccessLog\x12\x15\n\x04path\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x10\n\x06\x66ormat\x18\x02 \x01(\tH\x00\x12.\n\x0bjson_format\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructH\x00\x12\x34\n\x11typed_json_format\x18\x04 \x01(\x0b\x32\x17.google.protobuf.StructH\x00\x42\x13\n\x11\x61\x63\x63\x65ss_log_formatB\xbb\x01\n\'io.envoyproxy.envoy.config.accesslog.v2B\tFileProtoP\x01ZLgithub.com/envoyproxy/go-control-plane/envoy/config/accesslog/v2;accesslogv2\xf2\x98\xfe\x8f\x05)\x12\'envoy.extensions.access_loggers.file.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.accesslog.v2.file_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\'io.envoyproxy.envoy.config.accesslog.v2B\tFileProtoP\001ZLgithub.com/envoyproxy/go-control-plane/envoy/config/accesslog/v2;accesslogv2\362\230\376\217\005)\022\'envoy.extensions.access_loggers.file.v3\272\200\310\321\006\002\020\001'
  _globals['_FILEACCESSLOG'].fields_by_name['path']._loaded_options = None
  _globals['_FILEACCESSLOG'].fields_by_name['path']._serialized_options = b'\372B\004r\002 \001'
  _globals['_FILEACCESSLOG']._serialized_start=186
  _globals['_FILEACCESSLOG']._serialized_end=365
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/config/filter/network/kafka_broker/v2alpha1/kafka_broker.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/config/filter/network/kafka_broker/v2alpha1/kafka_broker.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDenvoy/config/filter/network/kafka_broker/v2alpha1/kafka_broker.proto\x12\x31\x65nvoy.config.filter.network.kafka_broker.v2alpha1\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xbe\x02\n\x0bKafkaBroker\x12\x1c\n\x0bstat_prefix\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x1e\n\x16\x66orce_response_rewrite\x18\x02 \x01(\x08\x12{\n$id_based_broker_address_rewrite_spec\x18\x03 \x01(\x0b\x32K.envoy.config.filter.network.kafka_broker.v2alpha1.IdBasedBrokerRewriteSpecH\x00\x12*\n\x10\x61pi_keys_allowed\x18\x04 \x03(\rB\x10\xfa\x42\r\x92\x01\n\"\x08*\x06\x18\xff\xff\x01(\x00\x12)\n\x0f\x61pi_keys_denied\x18\x05 \x03(\rB\x10\xfa\x42\r\x92\x01\n\"\x08*\x06\x18\xff\xff\x01(\x00\x42\x1d\n\x1b\x62roker_address_rewrite_spec\"v\n\x18IdBasedBrokerRewriteSpec\x12Z\n\x05rules\x18\x01 \x03(\x0b\x32K.envoy.config.filter.network.kafka_broker.v2alpha1.IdBasedBrokerRewriteRule\"_\n\x18IdBasedBrokerRewriteRule\x12\x13\n\x02id\x18\x01 \x01(\rB\x07\xfa\x42\x04*\x02(\x00\x12\x15\n\x04host\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x17\n\x04port\x18\x03 \x01(\rB\t\xfa\x42\x06*\x04\x18\xff\xff\x03\x42\xef\x01\n?io.envoyproxy.envoy.config.filter.network.kafka_broker.v2alpha1B\x10KafkaBrokerProtoP\x01ZXgithub.com/envoyproxy/go-control-plane/envoy/config/filter/network/kafka_broker/v2alpha1\xf2\x98\xfe\x8f\x05\x32\x12\x30\x65nvoy.extensions.filters.network.kafka_broker.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.filter.network.kafka_broker.v2alpha1.kafka_broker_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n?io.envoyproxy.envoy.config.filter.network.kafka_broker.v2alpha1B\020KafkaBrokerProtoP\001ZXgithub.com/envoyproxy/go-control-plane/envoy/config/filter/network/kafka_broker/v2alpha1\362\230\376\217\0052\0220envoy.extensions.filters.network.kafka_broker.v3\272\200\310\321\006\002\020\001'
  _globals['_KAFKABROKER'].fields_by_name['stat_prefix']._loaded_options = None
  _globals['_KAFKABROKER'].fields_by_name['stat_prefix']._serialized_options = b'\372B\004r\002 \001'
  _globals['_KAFKABROKER'].fields_by_name['api_keys_allowed']._loaded_options = None
  _globals['_KAFKABROKER'].fields_by_name['api_keys_allowed']._serialized_options = b'\372B\r\222\001\n\"\010*\006\030\377\377\001(\000'
  _globals['_KAFKABROKER'].fields_by_name['api_keys_denied']._loaded_options = None
  _globals['_KAFKABROKER'].fields_by_name['api_keys_denied']._serialized_options = b'\372B\r\222\001\n\"\010*\006\030\377\377\001(\000'
  _globals['_IDBASEDBROKERREWRITERULE'].fields_by_name['id']._loaded_options = None
  _globals['_IDBASEDBROKERREWRITERULE'].fields_by_name['id']._serialized_options = b'\372B\004*\002(\000'
  _globals['_IDBASEDBROKERREWRITERULE'].fields_by_name['host']._loaded_options = None
  _globals['_IDBASEDBROKERREWRITERULE'].fields_by_name['host']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_IDBASEDBROKERREWRITERULE'].fields_by_name['port']._loaded_options = None
  _globals['_IDBASEDBROKERREWRITERULE'].fields_by_name['port']._serialized_options = b'\372B\006*\004\030\377\377\003'
  _globals['_KAFKABROKER']._serialized_start=212
  _globals['_KAFKABROKER']._serialized_end=530
  _globals['_IDBASEDBROKERREWRITESPEC']._serialized_start=532
  _globals['_IDBASEDBROKERREWRITESPEC']._serialized_end=650
  _globals['_IDBASEDBROKERREWRITERULE']._serialized_start=652
  _globals['_IDBASEDBROKERREWRITERULE']._serialized_end=747
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/type/v3/hash_policy.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/type/v3/hash_policy.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x65nvoy/type/v3/hash_policy.proto\x12\renvoy.type.v3\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\x93\x02\n\nHashPolicy\x12\x37\n\tsource_ip\x18\x01 \x01(\x0b\x32\".envoy.type.v3.HashPolicy.SourceIpH\x00\x12=\n\x0c\x66ilter_state\x18\x02 \x01(\x0b\x32%.envoy.type.v3.HashPolicy.FilterStateH\x00\x1a\x31\n\x08SourceIp:%\x9a\xc5\x88\x1e \n\x1e\x65nvoy.type.HashPolicy.SourceIp\x1a#\n\x0b\x46ilterState\x12\x14\n\x03key\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01:\x1c\x9a\xc5\x88\x1e\x17\n\x15\x65nvoy.type.HashPolicyB\x17\n\x10policy_specifier\x12\x03\xf8\x42\x01\x42u\n\x1bio.envoyproxy.envoy.type.v3B\x0fHashPolicyProtoP\x01Z;github.com/envoyproxy/go-control-plane/envoy/type/v3;typev3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.type.v3.hash_policy_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033io.envoyproxy.envoy.type.v3B\017HashPolicyProtoP\001Z;github.com/envoyproxy/go-control-plane/envoy/type/v3;typev3\272\200\310\321\006\002\020\002'
  _globals['_HASHPOLICY_SOURCEIP']._loaded_options = None
  _globals['_HASHPOLICY_SOURCEIP']._serialized_options = b'\232\305\210\036 \n\036envoy.type.HashPolicy.SourceIp'
  _globals['_HASHPOLICY_FILTERSTATE'].fields_by_name['key']._loaded_options = None
  _globals['_HASHPOLICY_FILTERSTATE'].fields_by_name['key']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_HASHPOLICY'].oneofs_by_name['policy_specifier']._loaded_options = None
  _globals['_HASHPOLICY'].oneofs_by_name['policy_specifier']._serialized_options = b'\370B\001'
  _globals['_HASHPOLICY']._loaded_options = None
  _globals['_HASHPOLICY']._serialized_options = b'\232\305\210\036\027\n\025envoy.type.HashPolicy'
  _globals['_HASHPOLICY']._serialized_start=142
  _globals['_HASHPOLICY']._serialized_end=417
  _globals['_HASHPOLICY_SOURCEIP']._serialized_start=276
  _globals['_HASHPOLICY_SOURCEIP']._serialized_end=325
  _globals['_HASHPOLICY_FILTERSTATE']._serialized_start=327
  _globals['_HASHPOLICY_FILTERSTATE']._serialized_end=362
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/extensions/filters/http/jwt_authn/v3/config.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/extensions/filters/http/jwt_authn/v3/config.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.config.core.v3 import http_uri_pb2 as envoy_dot_config_dot_core_dot_v3_dot_http__uri__pb2
from envoy.config.route.v3 import route_components_pb2 as envoy_dot_config_dot_route_dot_v3_dot_route__components__pb2
from envoy.type.matcher.v3 import string_pb2 as envoy_dot_type_dot_matcher_dot_v3_dot_string__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7envoy/extensions/filters/http/jwt_authn/v3/config.proto\x12*envoy.extensions.filters.http.jwt_authn.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a#envoy/config/core/v3/http_uri.proto\x1a,envoy/config/route/v3/route_components.proto\x1a\"envoy/type/matcher/v3/string.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xd9\x08\n\x0bJwtProvider\x12\x0e\n\x06issuer\x18\x01 \x01(\t\x12\x11\n\taudiences\x18\x02 \x03(\t\x12\x36\n\x08subjects\x18\x13 \x01(\x0b\x32$.envoy.type.matcher.v3.StringMatcher\x12\x1a\n\x12require_expiration\x18\x14 \x01(\x08\x12/\n\x0cmax_lifetime\x18\x15 \x01(\x0b\x32\x19.google.protobuf.Duration\x12M\n\x0bremote_jwks\x18\x03 \x01(\x0b\x32\x36.envoy.extensions.filters.http.jwt_authn.v3.RemoteJwksH\x00\x12\x36\n\nlocal_jwks\x18\x04 \x01(\x0b\x32 .envoy.config.core.v3.DataSourceH\x00\x12\x0f\n\x07\x66orward\x18\x05 \x01(\x08\x12K\n\x0c\x66rom_headers\x18\x06 \x03(\x0b\x32\x35.envoy.extensions.filters.http.jwt_authn.v3.JwtHeader\x12\x13\n\x0b\x66rom_params\x18\x07 \x03(\t\x12\x14\n\x0c\x66rom_cookies\x18\r \x03(\t\x12+\n\x16\x66orward_payload_header\x18\x08 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x01\xc8\x01\x00\x12\"\n\x1apad_forward_payload_header\x18\x0b \x01(\x08\x12\x1b\n\x13payload_in_metadata\x18\t \x01(\t\x12o\n\x1dnormalize_payload_in_metadata\x18\x12 \x01(\x0b\x32H.envoy.extensions.filters.http.jwt_authn.v3.JwtProvider.NormalizePayload\x12\x1a\n\x12header_in_metadata\x18\x0e \x01(\t\x12!\n\x19\x66\x61iled_status_in_metadata\x18\x10 \x01(\t\x12\x1a\n\x12\x63lock_skew_seconds\x18\n \x01(\r\x12T\n\x10jwt_cache_config\x18\x0c \x01(\x0b\x32:.envoy.extensions.filters.http.jwt_authn.v3.JwtCacheConfig\x12V\n\x10\x63laim_to_headers\x18\x0f \x03(\x0b\x32<.envoy.extensions.filters.http.jwt_authn.v3.JwtClaimToHeader\x12\x19\n\x11\x63lear_route_cache\x18\x11 \x01(\x08\x1a\x32\n\x10NormalizePayload\x12\x1e\n\x16space_delimited_claims\x18\x01 \x03(\t:=\x9a\xc5\x88\x1e\x38\n6envoy.config.filter.http.jwt_authn.v2alpha.JwtProviderB\x1c\n\x15jwks_source_specifier\x12\x03\xf8\x42\x01\"(\n\x0eJwtCacheConfig\x12\x16\n\x0ejwt_cache_size\x18\x01 \x01(\r\"\xd8\x02\n\nRemoteJwks\x12\x39\n\x08http_uri\x18\x01 \x01(\x0b\x32\x1d.envoy.config.core.v3.HttpUriB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12G\n\x0e\x63\x61\x63he_duration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x14\xfa\x42\x11\xaa\x01\x0e\x1a\x06\x08\x80\xb4\xc4\xc3!2\x04\x10\xc0\x84=\x12O\n\x0b\x61sync_fetch\x18\x03 \x01(\x0b\x32:.envoy.extensions.filters.http.jwt_authn.v3.JwksAsyncFetch\x12\x37\n\x0cretry_policy\x18\x04 \x01(\x0b\x32!.envoy.config.core.v3.RetryPolicy:<\x9a\xc5\x88\x1e\x37\n5envoy.config.filter.http.jwt_authn.v2alpha.RemoteJwks\"c\n\x0eJwksAsyncFetch\x12\x15\n\rfast_listener\x18\x01 \x01(\x08\x12:\n\x17\x66\x61iled_refetch_duration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\"\x88\x01\n\tJwtHeader\x12\x1b\n\x04name\x18\x01 \x01(\tB\r\xfa\x42\nr\x08\x10\x01\xc0\x01\x01\xc8\x01\x00\x12!\n\x0cvalue_prefix\x18\x02 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x02\xc8\x01\x00:;\x9a\xc5\x88\x1e\x36\n4envoy.config.filter.http.jwt_authn.v2alpha.JwtHeader\"\x8a\x01\n\x15ProviderWithAudiences\x12\x15\n\rprovider_name\x18\x01 \x01(\t\x12\x11\n\taudiences\x18\x02 \x03(\t:G\x9a\xc5\x88\x1e\x42\n@envoy.config.filter.http.jwt_authn.v2alpha.ProviderWithAudiences\"\x82\x04\n\x0eJwtRequirement\x12\x17\n\rprovider_name\x18\x01 \x01(\tH\x00\x12\x63\n\x16provider_and_audiences\x18\x02 \x01(\x0b\x32\x41.envoy.extensions.filters.http.jwt_authn.v3.ProviderWithAudiencesH\x00\x12X\n\x0crequires_any\x18\x03 \x01(\x0b\x32@.envoy.extensions.filters.http.jwt_authn.v3.JwtRequirementOrListH\x00\x12Y\n\x0crequires_all\x18\x04 \x01(\x0b\x32\x41.envoy.extensions.filters.http.jwt_authn.v3.JwtRequirementAndListH\x00\x12\x39\n\x17\x61llow_missing_or_failed\x18\x05 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12/\n\rallow_missing\x18\x06 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00:@\x9a\xc5\x88\x1e;\n9envoy.config.filter.http.jwt_authn.v2alpha.JwtRequirementB\x0f\n\rrequires_type\"\xba\x01\n\x14JwtRequirementOrList\x12Z\n\x0crequirements\x18\x01 \x03(\x0b\x32:.envoy.extensions.filters.http.jwt_authn.v3.JwtRequirementB\x08\xfa\x42\x05\x92\x01\x02\x08\x02:F\x9a\xc5\x88\x1e\x41\n?envoy.config.filter.http.jwt_authn.v2alpha.JwtRequirementOrList\"\xbc\x01\n\x15JwtRequirementAndList\x12Z\n\x0crequirements\x18\x01 \x03(\x0b\x32:.envoy.extensions.filters.http.jwt_authn.v3.JwtRequirementB\x08\xfa\x42\x05\x92\x01\x02\x08\x02:G\x9a\xc5\x88\x1e\x42\n@envoy.config.filter.http.jwt_authn.v2alpha.JwtRequirementAndList\"\x99\x02\n\x0fRequirementRule\x12:\n\x05match\x18\x01 \x01(\x0b\x32!.envoy.config.route.v3.RouteMatchB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12N\n\x08requires\x18\x02 \x01(\x0b\x32:.envoy.extensions.filters.http.jwt_authn.v3.JwtRequirementH\x00\x12#\n\x10requirement_name\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00:A\x9a\xc5\x88\x1e<\n:envoy.config.filter.http.jwt_authn.v2alpha.RequirementRuleB\x12\n\x10requirement_type\"\xb5\x02\n\x0f\x46ilterStateRule\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12[\n\x08requires\x18\x03 \x03(\x0b\x32I.envoy.extensions.filters.http.jwt_authn.v3.FilterStateRule.RequiresEntry\x1ak\n\rRequiresEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12I\n\x05value\x18\x02 \x01(\x0b\x32:.envoy.extensions.filters.http.jwt_authn.v3.JwtRequirement:\x02\x38\x01:A\x9a\xc5\x88\x1e<\n:envoy.config.filter.http.jwt_authn.v2alpha.FilterStateRule\"\xe7\x05\n\x11JwtAuthentication\x12_\n\tproviders\x18\x01 \x03(\x0b\x32L.envoy.extensions.filters.http.jwt_authn.v3.JwtAuthentication.ProvidersEntry\x12J\n\x05rules\x18\x02 \x03(\x0b\x32;.envoy.extensions.filters.http.jwt_authn.v3.RequirementRule\x12W\n\x12\x66ilter_state_rules\x18\x03 \x01(\x0b\x32;.envoy.extensions.filters.http.jwt_authn.v3.FilterStateRule\x12\x1d\n\x15\x62ypass_cors_preflight\x18\x04 \x01(\x08\x12j\n\x0frequirement_map\x18\x05 \x03(\x0b\x32Q.envoy.extensions.filters.http.jwt_authn.v3.JwtAuthentication.RequirementMapEntry\x12\x1e\n\x16strip_failure_response\x18\x06 \x01(\x08\x1ai\n\x0eProvidersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x46\n\x05value\x18\x02 \x01(\x0b\x32\x37.envoy.extensions.filters.http.jwt_authn.v3.JwtProvider:\x02\x38\x01\x1aq\n\x13RequirementMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12I\n\x05value\x18\x02 \x01(\x0b\x32:.envoy.extensions.filters.http.jwt_authn.v3.JwtRequirement:\x02\x38\x01:C\x9a\xc5\x88\x1e>\n<envoy.config.filter.http.jwt_authn.v2alpha.JwtAuthentication\"p\n\x0ePerRouteConfig\x12\x1b\n\x08\x64isabled\x18\x01 \x01(\x08\x42\x07\xfa\x42\x04j\x02\x08\x01H\x00\x12#\n\x10requirement_name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00\x42\x1c\n\x15requirement_specifier\x12\x03\xf8\x42\x01\"S\n\x10JwtClaimToHeader\x12\"\n\x0bheader_name\x18\x01 \x01(\tB\r\xfa\x42\nr\x08\x10\x01\xc0\x01\x01\xc8\x01\x00\x12\x1b\n\nclaim_name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x42\xb0\x01\n8io.envoyproxy.envoy.extensions.filters.http.jwt_authn.v3B\x0b\x43onfigProtoP\x01Z]github.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/jwt_authn/v3;jwt_authnv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.jwt_authn.v3.config_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n8io.envoyproxy.envoy.extensions.filters.http.jwt_authn.v3B\013ConfigProtoP\001Z]github.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/jwt_authn/v3;jwt_authnv3\272\200\310\321\006\002\020\002'
  _globals['_JWTPROVIDER'].oneofs_by_name['jwks_source_specifier']._loaded_options = None
  _globals['_JWTPROVIDER'].oneofs_by_name['jwks_source_specifier']._serialized_options = b'\370B\001'
  _globals['_JWTPROVIDER'].fields_by_name['forward_payload_header']._loaded_options = None
  _globals['_JWTPROVIDER'].fields_by_name['forward_payload_header']._serialized_options = b'\372B\010r\006\300\001\001\310\001\000'
  _globals['_JWTPROVIDER']._loaded_options = None
  _globals['_JWTPROVIDER']._serialized_options = b'\232\305\210\0368\n6envoy.config.filter.http.jwt_authn.v2alpha.JwtProvider'
  _globals['_REMOTEJWKS'].fields_by_name['http_uri']._loaded_options = None
  _globals['_REMOTEJWKS'].fields_by_name['http_uri']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_REMOTEJWKS'].fields_by_name['cache_duration']._loaded_options = None
  _globals['_REMOTEJWKS'].fields_by_name['cache_duration']._serialized_options = b'\372B\021\252\001\016\032\006\010\200\264\304\303!2\004\020\300\204='
  _globals['_REMOTEJWKS']._loaded_options = None
  _globals['_REMOTEJWKS']._serialized_options = b'\232\305\210\0367\n5envoy.config.filter.http.jwt_authn.v2alpha.RemoteJwks'
  _globals['_JWTHEADER'].fields_by_name['name']._loaded_options = None
  _globals['_JWTHEADER'].fields_by_name['name']._serialized_options = b'\372B\nr\010\020\001\300\001\001\310\001\000'
  _globals['_JWTHEADER'].fields_by_name['value_prefix']._loaded_options = None
  _globals['_JWTHEADER'].fields_by_name['value_prefix']._serialized_options = b'\372B\010r\006\300\001\002\310\001\000'
  _globals['_JWTHEADER']._loaded_options = None
  _globals['_JWTHEADER']._serialized_options = b'\232\305\210\0366\n4envoy.config.filter.http.jwt_authn.v2alpha.JwtHeader'
  _globals['_PROVIDERWITHAUDIENCES']._loaded_options = None
  _globals['_PROVIDERWITHAUDIENCES']._serialized_options = b'\232\305\210\036B\n@envoy.config.filter.http.jwt_authn.v2alpha.ProviderWithAudiences'
  _globals['_JWTREQUIREMENT']._loaded_options = None
  _globals['_JWTREQUIREMENT']._serialized_options = b'\232\305\210\036;\n9envoy.config.filter.http.jwt_authn.v2alpha.JwtRequirement'
  _globals['_JWTREQUIREMENTORLIST'].fields_by_name['requirements']._loaded_options = None
  _globals['_JWTREQUIREMENTORLIST'].fields_by_name['requirements']._serialized_options = b'\372B\005\222\001\002\010\002'
  _globals['_JWTREQUIREMENTORLIST']._loaded_options = None
  _globals['_JWTREQUIREMENTORLIST']._serialized_options = b'\232\305\210\036A\n?envoy.config.filter.http.jwt_authn.v2alpha.JwtRequirementOrList'
  _globals['_JWTREQUIREMENTANDLIST'].fields_by_name['requirements']._loaded_options = None
  _globals['_JWTREQUIREMENTANDLIST'].fields_by_name['requirements']._serialized_options = b'\372B\005\222\001\002\010\002'
  _globals['_JWTREQUIREMENTANDLIST']._loaded_options = None
  _globals['_JWTREQUIREMENTANDLIST']._serialized_options = b'\232\305\210\036B\n@envoy.config.filter.http.jwt_authn.v2alpha.JwtRequirementAndList'
  _globals['_REQUIREMENTRULE'].fields_by_name['match']._loaded_options = None
  _globals['_REQUIREMENTRULE'].fields_by_name['match']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_REQUIREMENTRULE'].fields_by_name['requirement_name']._loaded_options = None
  _globals['_REQUIREMENTRULE'].fields_by_name['requirement_name']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_REQUIREMENTRULE']._loaded_options = None
  _globals['_REQUIREMENTRULE']._serialized_options = b'\232\305\210\036<\n:envoy.config.filter.http.jwt_authn.v2alpha.RequirementRule'
  _globals['_FILTERSTATERULE_REQUIRESENTRY']._loaded_options = None
  _globals['_FILTERSTATERULE_REQUIRESENTRY']._serialized_options = b'8\001'
  _globals['_FILTERSTATERULE'].fields_by_name['name']._loaded_options = None
  _globals['_FILTERSTATERULE'].fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_FILTERSTATERULE']._loaded_options = None
  _globals['_FILTERSTATERULE']._serialized_options = b'\232\305\210\036<\n:envoy.config.filter.http.jwt_authn.v2alpha.FilterStateRule'
  _globals['_JWTAUTHENTICATION_PROVIDERSENTRY']._loaded_options = None
  _globals['_JWTAUTHENTICATION_PROVIDERSENTRY']._serialized_options = b'8\001'
  _globals['_JWTAUTHENTICATION_REQUIREMENTMAPENTRY']._loaded_options = None
  _globals['_JWTAUTHENTICATION_REQUIREMENTMAPENTRY']._serialized_options = b'8\001'
  _globals['_JWTAUTHENTICATION']._loaded_options = None
  _globals['_JWTAUTHENTICATION']._serialized_options = b'\232\305\210\036>\n<envoy.config.filter.http.jwt_authn.v2alpha.JwtAuthentication'
  _globals['_PERROUTECONFIG'].oneofs_by_name['requirement_specifier']._loaded_options = None
  _globals['_PERROUTECONFIG'].oneofs_by_name['requirement_specifier']._serialized_options = b'\370B\001'
  _globals['_PERROUTECONFIG'].fields_by_name['disabled']._loaded_options = None
  _globals['_PERROUTECONFIG'].fields_by_name['disabled']._serialized_options = b'\372B\004j\002\010\001'
  _globals['_PERROUTECONFIG'].fields_by_name['requirement_name']._loaded_options = None
  _globals['_PERROUTECONFIG'].fields_by_name['requirement_name']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_JWTCLAIMTOHEADER'].fields_by_name['header_name']._loaded_options = None
  _globals['_JWTCLAIMTOHEADER'].fields_by_name['header_name']._serialized_options = b'\372B\nr\010\020\001\300\001\001\310\001\000'
  _globals['_JWTCLAIMTOHEADER'].fields_by_name['claim_name']._loaded_options = None
  _globals['_JWTCLAIMTOHEADER'].fields_by_name['claim_name']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_JWTPROVIDER']._serialized_start=408
  _globals['_JWTPROVIDER']._serialized_end=1521
  _globals['_JWTPROVIDER_NORMALIZEPAYLOAD']._serialized_start=1378
  _globals['_JWTPROVIDER_NORMALIZEPAYLOAD']._serialized_end=1428
  _globals['_JWTCACHECONFIG']._serialized_start=1523
  _globals['_JWTCACHECONFIG']._serialized_end=1563
  _globals['_REMOTEJWKS']._serialized_start=1566
  _globals['_REMOTEJWKS']._serialized_end=1910
  _globals['_JWKSASYNCFETCH']._serialized_start=1912
  _globals['_JWKSASYNCFETCH']._serialized_end=2011
  _globals['_JWTHEADER']._serialized_start=2014
  _globals['_JWTHEADER']._serialized_end=2150
  _globals['_PROVIDERWITHAUDIENCES']._serialized_start=2153
  _globals['_PROVIDERWITHAUDIENCES']._serialized_end=2291
  _globals['_JWTREQUIREMENT']._serialized_start=2294
  _globals['_JWTREQUIREMENT']._serialized_end=2808
  _globals['_JWTREQUIREMENTORLIST']._serialized_start=2811
  _globals['_JWTREQUIREMENTORLIST']._serialized_end=2997
  _globals['_JWTREQUIREMENTANDLIST']._serialized_start=3000
  _globals['_JWTREQUIREMENTANDLIST']._serialized_end=3188
  _globals['_REQUIREMENTRULE']._serialized_start=3191
  _globals['_REQUIREMENTRULE']._serialized_end=3472
  _globals['_FILTERSTATERULE']._serialized_start=3475
  _globals['_FILTERSTATERULE']._serialized_end=3784
  _globals['_FILTERSTATERULE_REQUIRESENTRY']._serialized_start=3610
  _globals['_FILTERSTATERULE_REQUIRESENTRY']._serialized_end=3717
  _globals['_JWTAUTHENTICATION']._serialized_start=3787
  _globals['_JWTAUTHENTICATION']._serialized_end=4530
  _globals['_JWTAUTHENTICATION_PROVIDERSENTRY']._serialized_start=4241
  _globals['_JWTAUTHENTICATION_PROVIDERSENTRY']._serialized_end=4346
  _globals['_JWTAUTHENTICATION_REQUIREMENTMAPENTRY']._serialized_start=4348
  _globals['_JWTAUTHENTICATION_REQUIREMENTMAPENTRY']._serialized_end=4461
  _globals['_PERROUTECONFIG']._serialized_start=4532
  _globals['_PERROUTECONFIG']._serialized_end=4644
  _globals['_JWTCLAIMTOHEADER']._serialized_start=4646
  _globals['_JWTCLAIMTOHEADER']._serialized_end=4729
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: google/type/calendar_period.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'google/type/calendar_period.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!google/type/calendar_period.proto\x12\x0bgoogle.type*\x7f\n\x0e\x43\x61lendarPeriod\x12\x1f\n\x1b\x43\x41LENDAR_PERIOD_UNSPECIFIED\x10\x00\x12\x07\n\x03\x44\x41Y\x10\x01\x12\x08\n\x04WEEK\x10\x02\x12\r\n\tFORTNIGHT\x10\x03\x12\t\n\x05MONTH\x10\x04\x12\x0b\n\x07QUARTER\x10\x05\x12\x08\n\x04HALF\x10\x06\x12\x08\n\x04YEAR\x10\x07\x42x\n\x0f\x63om.google.typeB\x13\x43\x61lendarPeriodProtoP\x01ZHgoogle.golang.org/genproto/googleapis/type/calendarperiod;calendarperiod\xa2\x02\x03GTPb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.type.calendar_period_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\017com.google.typeB\023CalendarPeriodProtoP\001ZHgoogle.golang.org/genproto/googleapis/type/calendarperiod;calendarperiod\242\002\003GTP'
  _globals['_CALENDARPERIOD']._serialized_start=50
  _globals['_CALENDARPERIOD']._serialized_end=177
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/extensions/transport_sockets/starttls/v3/starttls.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/extensions/transport_sockets/starttls/v3/starttls.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.extensions.transport_sockets.raw_buffer.v3 import raw_buffer_pb2 as envoy_dot_extensions_dot_transport__sockets_dot_raw__buffer_dot_v3_dot_raw__buffer__pb2
from envoy.extensions.transport_sockets.tls.v3 import tls_pb2 as envoy_dot_extensions_dot_transport__sockets_dot_tls_dot_v3_dot_tls__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=envoy/extensions/transport_sockets/starttls/v3/starttls.proto\x12.envoy.extensions.transport_sockets.starttls.v3\x1a\x41\x65nvoy/extensions/transport_sockets/raw_buffer/v3/raw_buffer.proto\x1a\x33\x65nvoy/extensions/transport_sockets/tls/v3/tls.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xd4\x01\n\x0eStartTlsConfig\x12\\\n\x17\x63leartext_socket_config\x18\x01 \x01(\x0b\x32;.envoy.extensions.transport_sockets.raw_buffer.v3.RawBuffer\x12\x64\n\x11tls_socket_config\x18\x02 \x01(\x0b\x32?.envoy.extensions.transport_sockets.tls.v3.DownstreamTlsContextB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\"\xda\x01\n\x16UpstreamStartTlsConfig\x12\\\n\x17\x63leartext_socket_config\x18\x01 \x01(\x0b\x32;.envoy.extensions.transport_sockets.raw_buffer.v3.RawBuffer\x12\x62\n\x11tls_socket_config\x18\x02 \x01(\x0b\x32=.envoy.extensions.transport_sockets.tls.v3.UpstreamTlsContextB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x42\xb9\x01\n<io.envoyproxy.envoy.extensions.transport_sockets.starttls.v3B\rStarttlsProtoP\x01Z`github.com/envoyproxy/go-control-plane/envoy/extensions/transport_sockets/starttls/v3;starttlsv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.transport_sockets.starttls.v3.starttls_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n<io.envoyproxy.envoy.extensions.transport_sockets.starttls.v3B\rStarttlsProtoP\001Z`github.com/envoyproxy/go-control-plane/envoy/extensions/transport_sockets/starttls/v3;starttlsv3\272\200\310\321\006\002\020\002'
  _globals['_STARTTLSCONFIG'].fields_by_name['tls_socket_config']._loaded_options = None
  _globals['_STARTTLSCONFIG'].fields_by_name['tls_socket_config']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_UPSTREAMSTARTTLSCONFIG'].fields_by_name['tls_socket_config']._loaded_options = None
  _globals['_UPSTREAMSTARTTLSCONFIG'].fields_by_name['tls_socket_config']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_STARTTLSCONFIG']._serialized_start=290
  _globals['_STARTTLSCONFIG']._serialized_end=502
  _globals['_UPSTREAMSTARTTLSCONFIG']._serialized_start=505
  _globals['_UPSTREAMSTARTTLSCONFIG']._serialized_end=723
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: google/api/visibility.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'google/api/visibility.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bgoogle/api/visibility.proto\x12\ngoogle.api\x1a google/protobuf/descriptor.proto\"7\n\nVisibility\x12)\n\x05rules\x18\x01 \x03(\x0b\x32\x1a.google.api.VisibilityRule\"7\n\x0eVisibilityRule\x12\x10\n\x08selector\x18\x01 \x01(\t\x12\x13\n\x0brestriction\x18\x02 \x01(\t:T\n\x0f\x65num_visibility\x12\x1c.google.protobuf.EnumOptions\x18\xaf\xca\xbc\" \x01(\x0b\x32\x1a.google.api.VisibilityRule:Z\n\x10value_visibility\x12!.google.protobuf.EnumValueOptions\x18\xaf\xca\xbc\" \x01(\x0b\x32\x1a.google.api.VisibilityRule:V\n\x10\x66ield_visibility\x12\x1d.google.protobuf.FieldOptions\x18\xaf\xca\xbc\" \x01(\x0b\x32\x1a.google.api.VisibilityRule:Z\n\x12message_visibility\x12\x1f.google.protobuf.MessageOptions\x18\xaf\xca\xbc\" \x01(\x0b\x32\x1a.google.api.VisibilityRule:X\n\x11method_visibility\x12\x1e.google.protobuf.MethodOptions\x18\xaf\xca\xbc\" \x01(\x0b\x32\x1a.google.api.VisibilityRule:V\n\x0e\x61pi_visibility\x12\x1f.google.protobuf.ServiceOptions\x18\xaf\xca\xbc\" \x01(\x0b\x32\x1a.google.api.VisibilityRuleBn\n\x0e\x63om.google.apiB\x0fVisibilityProtoP\x01Z?google.golang.org/genproto/googleapis/api/visibility;visibility\xf8\x01\x01\xa2\x02\x04GAPIb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.api.visibility_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\016com.google.apiB\017VisibilityProtoP\001Z?google.golang.org/genproto/googleapis/api/visibility;visibility\370\001\001\242\002\004GAPI'
  _globals['_VISIBILITY']._serialized_start=77
  _globals['_VISIBILITY']._serialized_end=132
  _globals['_VISIBILITYRULE']._serialized_start=134
  _globals['_VISIBILITYRULE']._serialized_end=189
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/service/auth/v2/attribute_context.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/service/auth/v2/attribute_context.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import address_pb2 as envoy_dot_api_dot_v2_dot_core_dot_address__pb2
from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-envoy/service/auth/v2/attribute_context.proto\x12\x15\x65nvoy.service.auth.v2\x1a\x1f\x65nvoy/api/v2/core/address.proto\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dudpa/annotations/status.proto\"\xac\x08\n\x10\x41ttributeContext\x12<\n\x06source\x18\x01 \x01(\x0b\x32,.envoy.service.auth.v2.AttributeContext.Peer\x12\x41\n\x0b\x64\x65stination\x18\x02 \x01(\x0b\x32,.envoy.service.auth.v2.AttributeContext.Peer\x12@\n\x07request\x18\x04 \x01(\x0b\x32/.envoy.service.auth.v2.AttributeContext.Request\x12Z\n\x12\x63ontext_extensions\x18\n \x03(\x0b\x32>.envoy.service.auth.v2.AttributeContext.ContextExtensionsEntry\x12\x35\n\x10metadata_context\x18\x0b \x01(\x0b\x32\x1b.envoy.api.v2.core.Metadata\x1a\xe5\x01\n\x04Peer\x12+\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0b\x32\x1a.envoy.api.v2.core.Address\x12\x0f\n\x07service\x18\x02 \x01(\t\x12H\n\x06labels\x18\x03 \x03(\x0b\x32\x38.envoy.service.auth.v2.AttributeContext.Peer.LabelsEntry\x12\x11\n\tprincipal\x18\x04 \x01(\t\x12\x13\n\x0b\x63\x65rtificate\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1av\n\x07Request\x12(\n\x04time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x41\n\x04http\x18\x02 \x01(\x0b\x32\x33.envoy.service.auth.v2.AttributeContext.HttpRequest\x1a\xa7\x02\n\x0bHttpRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06method\x18\x02 \x01(\t\x12Q\n\x07headers\x18\x03 \x03(\x0b\x32@.envoy.service.auth.v2.AttributeContext.HttpRequest.HeadersEntry\x12\x0c\n\x04path\x18\x04 \x01(\t\x12\x0c\n\x04host\x18\x05 \x01(\t\x12\x0e\n\x06scheme\x18\x06 \x01(\t\x12\r\n\x05query\x18\x07 \x01(\t\x12\x10\n\x08\x66ragment\x18\x08 \x01(\t\x12\x0c\n\x04size\x18\t \x01(\x03\x12\x10\n\x08protocol\x18\n \x01(\t\x12\x0c\n\x04\x62ody\x18\x0b \x01(\t\x1a.\n\x0cHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x38\n\x16\x43ontextExtensionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x8b\x01\n#io.envoyproxy.envoy.service.auth.v2B\x15\x41ttributeContextProtoP\x01ZCgithub.com/envoyproxy/go-control-plane/envoy/service/auth/v2;authv2\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.service.auth.v2.attribute_context_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n#io.envoyproxy.envoy.service.auth.v2B\025AttributeContextProtoP\001ZCgithub.com/envoyproxy/go-control-plane/envoy/service/auth/v2;authv2\272\200\310\321\006\002\020\001'
  _globals['_ATTRIBUTECONTEXT_PEER_LABELSENTRY']._loaded_options = None
  _globals['_ATTRIBUTECONTEXT_PEER_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_ATTRIBUTECONTEXT_HTTPREQUEST_HEADERSENTRY']._loaded_options = None
  _globals['_ATTRIBUTECONTEXT_HTTPREQUEST_HEADERSENTRY']._serialized_options = b'8\001'
  _globals['_ATTRIBUTECONTEXT_CONTEXTEXTENSIONSENTRY']._loaded_options = None
  _globals['_ATTRIBUTECONTEXT_CONTEXTEXTENSIONSENTRY']._serialized_options = b'8\001'
  _globals['_ATTRIBUTECONTEXT']._serialized_start=200
  _globals['_ATTRIBUTECONTEXT']._serialized_end=1268
  _globals['_ATTRIBUTECONTEXT_PEER']._serialized_start=563
  _globals['_ATTRIBUTECONTEXT_PEER']._serialized_end=792
  _globals['_ATTRIBUTECONTEXT_PEER_LABELSENTRY']._serialized_start=747
  _globals['_ATTRIBUTECONTEXT_PEER_LABELSENTRY']._serialized_end=792
  _globals['_ATTRIBUTECONTEXT_REQUEST']._serialized_start=794
  _globals['_ATTRIBUTECONTEXT_REQUEST']._serialized_end=912
  _globals['_ATTRIBUTECONTEXT_HTTPREQUEST']._serialized_start=915
  _globals['_ATTRIBUTECONTEXT_HTTPREQUEST']._serialized_end=1210
  _globals['_ATTRIBUTECONTEXT_HTTPREQUEST_HEADERSENTRY']._serialized_start=1164
  _globals['_ATTRIBUTECONTEXT_HTTPREQUEST_HEADERSENTRY']._serialized_end=1210
  _globals['_ATTRIBUTECONTEXT_CONTEXTEXTENSIONSENTRY']._serialized_start=1212
  _globals['_ATTRIBUTECONTEXT_CONTEXTEXTENSIONSENTRY']._serialized_end=1268
# @@protoc_insertion_point(module_scope)
